@@ -64,7 +64,6 @@ class GraphQLNode():
         """
 
         formatted_args = ', '.join(['{}:{}'.format(key, value) for key, value in self.arguments.items()])
-        formatted_args = formatted_args.replace("'", '"')
         return '{} ({})'.format(body, formatted_args)
 
 
@@ -285,6 +284,12 @@ class GraphQLOperation(GraphQLField):
             body = '{} {} {{ {} }}'.format(self.action_type, var_format, body)
         else:
             body = '{} {{ {} }}'.format(self.action_type, body)
+        
+        import re
+        single_quotes = re.findall("\\'" + '".+"' + "\\'", body)
+        for quote in single_quotes:
+            repl = quote.replace("\'", "")
+            body = re.sub(quote, repl, body)
 
         return body
 
