@@ -2,6 +2,8 @@ import json
 
 from schematics.models import Model
 from schematics.types import StringType
+from datetime import datetime
+from moncli.config import DATE_FORMAT, TIME_FORMAT
 
 from .. import api, entities as en, models as m, error as e, column_value as cv
 from ..error import ItemError
@@ -226,7 +228,7 @@ class Item(_Item):
     def subitems(self):
         """The nested subitems."""
         if not self.__subitems:
-            self.__subitems = self.get_subitems()
+            self.__subitems = self.get_subitems(get_column_values=True)
         return self.__subitems
 
 
@@ -691,11 +693,13 @@ class Item(_Item):
         return self.column_values[id]
 
 
-    def get_subitems(self, *args):
+    def get_subitems(self, get_column_values = False, *args):
         """Get the subitems of an item.
 
             Parameters
 
+                get_column_values: `bool`:
+                    Retrieves item column values if set to `True`.
                 args: list
                     list of return field arguments
 
@@ -733,6 +737,13 @@ class Item(_Item):
                 updates : `moncli.entities.update.Update`
                     The item's updates.
         """
+        if get_column_values:
+            args = list(args)
+            for arg in ['column_values.{}'.format(arg) for arg in api.DEFAULT_COLUMN_VALUE_QUERY_FIELDS]:
+                if arg not in args:
+                    args.append(arg)
+            args.extend(['id', 'name'])
+
         subitems_data = api.get_items(
             *api.get_field_list(api.DEFAULT_ITEM_QUERY_FIELDS, 'subitems', *args),
             api_key=self.__creds.api_key_v2,
@@ -1065,6 +1076,12 @@ class Item(_Item):
             values = { value.id: value.format() for value in column_values }
         else:
             raise en.InvalidColumnValue(type(column_values).__name__)
+        for key,value in values.items():
+            if isinstance(value,datetime):
+                new_data = {}
+                new_data["date"]=value.date().strftime(DATE_FORMAT)
+                new_data["time"]=value.date().strftime(TIME_FORMAT)
+                values[key] = new_data
         item_data = api.change_multiple_column_value(
             self.id,
             self.board.id,
